@@ -21,7 +21,6 @@
 __author__ = 'Ramon Bartl <ramon.bartl@inquant.de>'
 __docformat__ = 'plaintext'
 
-import Zope2
 from zope.i18nmessageid import MessageFactory
 
 from collective.logbook import monkey
@@ -32,9 +31,10 @@ logbookMessageFactory = MessageFactory('collective.logbook')
 
 def initialize(context):
     """ Initializer called when used as a Zope 2 product. """
+    from Zope2 import bobo_application
+    app = bobo_application()
 
-    app = Zope2.app()
-    enabled = app.getProperty("logbook_enabled", False)
+    enabled = app is not None and app.getProperty("logbook_enabled", False)
 
     if enabled:
         monkey.install_monkey()
