@@ -39,6 +39,8 @@ from collective.logbook.config import LOGGER
 from collective.logbook.interfaces import ILogBook
 from collective.logbook.interfaces import ILogBookStorage
 
+from collective.logbook import logbookMessageFactory as _
+
 
 class LogBook(BrowserView):
     """ Logbook Form
@@ -84,10 +86,12 @@ class LogBook(BrowserView):
         error['time'] = DateTime(error['time'])
         return error
 
-    def save_error(self, err_id):
+    def save_error(self, err_id, context=None):
         """ see ILogBook
         """
         error = self.error(err_id)
+        if context is not None:
+            error['context'] = context
         return self.storage.save_error(error)
 
     def delete_error(self, err_id):
@@ -112,12 +116,13 @@ class LogBook(BrowserView):
         errors = self.storage.get_all_errors()
         out = []
         for id, tb in errors:
-            counter = self.storage.get_counter(id)
+            refs = self.storage.get_referenced_errordata(id)
             out.append(
                     dict(
                         id = id,
                         tb = tb,
-                        counter = counter,
+                        counter = len(refs),
+                        refs = refs
                         )
                     )
         return sorted(out, key=lambda x: x["counter"], reverse=True)
@@ -151,17 +156,17 @@ class LogBook(BrowserView):
                 for entry in entries:
                     err_id = entry.get('id')
                     if self.delete_error(err_id):
-                        IStatusMessage(self.request).addStatusMessage(u"Traceback %s deleted" % err_id, type='info')
+                        IStatusMessage(self.request).addStatusMessage(_(u"Traceback %s deleted") % err_id, type='info')
                     else:
-                        IStatusMessage(self.request).addStatusMessage(u"could not delete %s" % err_id, type='warning')
+                        IStatusMessage(self.request).addStatusMessage(_(u"could not delete %s") % err_id, type='warning')
 
             if delete_all_button:
                 self.delete_all_errors()
-                IStatusMessage(self.request).addStatusMessage(u"Deleted all Errors", type='info')
+                IStatusMessage(self.request).addStatusMessage(_(u"Deleted all Errors"), type='info')
 
             if delete_refs_button:
                 self.delete_all_references()
-                IStatusMessage(self.request).addStatusMessage(u"Deleted all referenced Error", type='info')
+                IStatusMessage(self.request).addStatusMessage(_(u"Deleted all referenced Error"), type='info')
 
         return self.template()
 
