@@ -18,7 +18,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__author__    = 'Ramon Bartl <ramon.bartl@inquant.de>'
+__author__ = 'Ramon Bartl <ramon.bartl@inquant.de>'
 __docformat__ = 'plaintext'
 
 import urllib
@@ -26,11 +26,10 @@ import transaction
 from thread import allocate_lock
 
 from zope import interface
-from zope.app.component import hooks
+
+from Acquisition import aq_parent
 
 from config import LOGGER
-from config import PROP_KEY_LOG_MAILS
-from utils import send
 
 from interfaces import IErrorRaisedEvent
 from interfaces import INotifyTraceback
@@ -38,18 +37,6 @@ from interfaces import INotifyTraceback
 
 cleanup_lock = allocate_lock()
 
-MAIL_TEMPLATE = """
-A new error occured on %(date)s
-
-%(traceback)s
-
-This error is saved under the number %(error_number)s
-
-The error occured here %(error_url)s
-
-Please check the logbook entry %(logbook_url)s
-"""
-
 
 class ErrorRaisedEvent(object):
     interface.implements(IErrorRaisedEvent)
@@ -70,30 +57,12 @@ class NotifyTraceback(object):
 def mailHandler(event):
     """ notify this error
     """
-    error = event.error
-    portal = hooks.getSite()
-    app = portal.getParentNode()
-    emails = app.getProperty(PROP_KEY_LOG_MAILS)
-
-    if not emails:
-        return
-
-    recipients = [mail for mail in emails]
-    subject = "[collective.logbook] NEW TRACEBACK: '%s'" % error.get("value")
-    data = dict(
-            date = error.get("time").strftime("%Y-%m-%d %H:%M:%S"),
-            traceback = error.get("tb_text"),
-            error_number = error.get("id"),
-            error_url = error.get("url"),
-            logbook_url = portal.absolute_url() + "/@@logbook?errornumber=%s" % error.get("id"),
-            )
-
     try:
-        message = MAIL_TEMPLATE % data
-        send(portal, message, subject, recipients)
-    except:
-        LOGGER.info("An error occured while notifying recipients")
-
+        return event.error['context'].restrictedTraverse(
+            '@@logbook_mail')(event)
+    except Exception, e:
+        LOGGER.error(
+            "An error occured while notifying recipients: %s" % str(e))
 
 
 def handleTraceback(object):
@@ -116,7 +85,9 @@ def handleTraceback(object):
             # get the generated error url from Products.SiteErrorLog
             err_id = urllib.splitvalue(entry_url)[1]
             # save error
-            logbook.save_error(err_id)
+            logbook.save_error(err_id, context=aq_parent(context))
+            transaction.get().note('collective.logbook traceback [%s]' %
+                    entry_url)
             transaction.commit()
         finally:
             cleanup_lock.release()
